# -*- coding: utf-8 -*-

from openfisca_senegal import CountryTaxBenefitSystem as SenegalTaxBenefitSystem

from openfisca_survey_manager.scenarios import AbstractSurveyScenario


class SenegalSurveyScenario(AbstractSurveyScenario):
    id_variable_by_entity_key = dict(
        famille = 'id_famille',
        )
    role_variable_by_entity_key = dict(
        famille = 'role_famille',
        )

    def __init__(self, input_data_frame = None, tax_benefit_system = None,
            reference_tax_benefit_system = None, year = None):
        super(SenegalSurveyScenario, self).__init__()
        assert input_data_frame is not None
        assert year is not None
        self.year = year
        if tax_benefit_system is None:
            tax_benefit_system = SenegalTaxBenefitSystem()
        self.set_tax_benefit_systems(
            tax_benefit_system = tax_benefit_system,
            reference_tax_benefit_system = reference_tax_benefit_system
            )
        self.used_as_input_variables = list(
            set(tax_benefit_system.column_by_name.keys()).intersection(
                set(input_data_frame.columns)
                ))
        self.init_from_data_frame(input_data_frame = input_data_frame)
        self.new_simulation()
        if reference_tax_benefit_system is not None:
            self.new_simulation(reference = True)





#! /usr/bin/env python
# -*- coding: utf-8 -*-


from setuptools import setup, find_packages


setup(
    name='OpenFisca-Senegal',
    version='0.4.0',
    author='OpenFisca Team',
    author_email='contact@openfisca.fr',
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Operating System :: POSIX",
        "Programming Language :: Python",
        "Topic :: Scientific/Engineering :: Information Analysis",
        ],
    description=u'Senegalese tax and benefit system for OpenFisca',
    keywords='benefit microsimulation senegal social tax',
    license='http://www.fsf.org/licensing/licenses/agpl-3.0.html',
    url='https://github.com/openfisca/senegal',

    data_files=[
        ('share/openfisca/openfisca-senegal',
         ['CHANGELOG.md', 'LICENSE', 'README.md']),
        ],
    extras_require={
        'api': [
            'OpenFisca-Web-Api[paster] == 3.0.1.dev0',
            ],
        'notebook': [
            'notebook',
            'matplotlib',
            ],
        'survey': [
            'OpenFisca-Survey-Manager >= 0.8.1',
            ]
        },
    include_package_data = True,  # Will read MANIFEST.in
    install_requires=[
        'OpenFisca-Core == 4.3.3',
        'PyYAML >= 3.10',
        ],
    packages=find_packages(exclude=['openfisca_senegal.tests*']),
    test_suite='nose.collector',
    )
